@@ -150,15 +150,24 @@ def connection(**kwargs):
     if kwargs:
         password = kwargs.pop("password")
         username = format_username(kwargs)
-    # Connect.
-    try:
-        c = ldap3.Connection(
+    # Build server pool
+    server_pool = ldap3.ServerPool(None, ldap3.RANDOM, active=True, exhaust=5)
+    auth_url = settings.LDAP_AUTH_URL
+    if not isinstance(auth_url, list):
+        auth_url = [auth_url]
+    for u in auth_url:
+        server_pool.add(
             ldap3.Server(
-                settings.LDAP_AUTH_URL,
+                u,
                 allowed_referral_hosts=[("*", True)],
                 get_info=ldap3.NONE,
                 connect_timeout=settings.LDAP_AUTH_CONNECT_TIMEOUT,
-            ),
+            )
+        )
+    # Connect.
+    try:
+        c = ldap3.Connection(
+            server_pool,
             user=username,
             password=password,
             auto_bind=False,
@@ -208,11 +217,18 @@ def authenticate(*args, **kwargs):
     in settings.LDAP_AUTH_USER_LOOKUP_FIELDS, plus a `password` argument.
     """
     password = kwargs.pop("password", None)
+    auth_user_lookup_fields = frozenset(settings.LDAP_AUTH_USER_LOOKUP_FIELDS)
+    ldap_kwargs = {
+        key: value for (key, value) in kwargs.items()
+        if key in auth_user_lookup_fields
+    }
+
     # Check that this is valid login data.
-    if not password or frozenset(kwargs.keys()) != frozenset(settings.LDAP_AUTH_USER_LOOKUP_FIELDS):
+    if not password or frozenset(ldap_kwargs.keys()) != auth_user_lookup_fields:
         return None
+
     # Connect to LDAP.
-    with connection(password=password, **kwargs) as c:
+    with connection(password=password, **ldap_kwargs) as c:
         if c is None:
             return None
-        return c.get_user(**kwargs)
+        return c.get_user(**ldap_kwargs)
